==> nextcloud-29.0.5.tgz: nextcloud/apps/oauth2/l10n/de.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Dein Client ist nicht berechtigt, eine Verbindung herzustellen. Bitte informiere den Administrator deines Clients.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Die Weiterleitungs-URL muss eine vollständige URL sein. Beispiel: https://deinedomain.com/pfad",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Ermöglicht OAuth2 komplatible Authentifizierung durch andere Web-Anwendungen.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "Die OAuth2-App ermöglicht es Administratoren den eingebauten Authenztifizierungsablauf dahingehend zu konfigurieren, das auch ein OAuth2 komplatible Authentifizierung von anderen Web-Anwendungen aus möglich ist. ",
    "OAuth 2.0 clients" : "OAuth 2.0-Clients",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 ermöglicht es externen Diensten, Zugriff auf {instanceName} anzufordern.",
    "Name" : "Name",
    "Redirection URI" : "Weiterleitungs-URI",
    "Client Identifier" : "Client-Identifikationsmerkmal",
    "Secret key" : "Geheimer Schlüssel",
    "Delete client" : "Client löschen",
    "Add client" : "Client hinzufügen",
    "Add" : "Hinzufügen",
    "Delete" : " Löschen",
    "Show client secret" : "Geheime Zeichenkette des Clients anzeigen",
    "Hide client secret" : "Geheime Zeichenkette des Clients ausblenden"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.9.tgz: nextcloud/apps/oauth2/l10n/de.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Dein Client ist nicht berechtigt, eine Verbindung herzustellen. Bitte informiere die Administration deines Clients.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Die Weiterleitungs-URL muss eine vollständige URL sein. Beispiel: https://deinedomain.com/pfad",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Ermöglicht OAuth2 komplatible Authentifizierung durch andere Web-Anwendungen.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "Die OAuth2-App ermöglicht es Administratoren den eingebauten Authenztifizierungsablauf dahingehend zu konfigurieren, das auch ein OAuth2 komplatible Authentifizierung von anderen Web-Anwendungen aus möglich ist. ",
    "OAuth 2.0 clients" : "OAuth 2.0-Clients",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 ermöglicht es externen Diensten, Zugriff auf {instanceName} anzufordern.",
    "Name" : "Name",
    "Redirection URI" : "Weiterleitungs-URI",
    "Client Identifier" : "Client-Identifikationsmerkmal",
    "Secret key" : "Geheimer Schlüssel",
    "Delete client" : "Client löschen",
    "Make sure you store the secret key, it cannot be recovered." : "Bewahre den geheimen Schlüssel unbedingt auf, er kann nicht wiederhergestellt werden.",
    "Add client" : "Client hinzufügen",
    "Add" : "Hinzufügen",
    "Show client secret" : "Geheime Zeichenkette des Clients anzeigen",
    "Hide client secret" : "Geheime Zeichenkette des Clients ausblenden",
    "Delete" : " Löschen"
},
"nplurals=2; plural=(n != 1);");
